@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Vanessa Sochat.
+# Copyright (C) 2017-2022 Vanessa Sochat.
 
 # This Source Code Form is subject to the terms of the
 # Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
@@ -155,6 +155,6 @@ class ParserBase(object):
         string: the string with replacements made
         """
         for key, value in args.items():
-            if re.search("\$(" + key + "|\{[^}]*\})", string):
-                string = re.sub("\$(" + key + "|\{[^}]*\})", value, string)
+            if re.search(r"\$(" + key + r"|\{[^}]*\})", string):
+                string = re.sub(r"\$(" + key + r"|\{[^}]*\})", value, string)
         return string
